package com.oauth.wrap.api.microsoft;

import java.util.HashMap;
import java.util.Map;

import org.apache.log4j.Logger;

import com.oauth.wrap.api.Api;
import com.oauth.wrap.extractor.AccessTokenExtractor;
import com.oauth.wrap.model.AccessToken;
import com.oauth.wrap.model.HttpVerb;
import com.oauth.wrap.model.Request;
import com.oauth.wrap.model.Response;
import com.oauth.wrap.model.Verifier;

/**
 * @author Oleksii Karpynskyi <okarpynskyi@gmail.com>
 * 
 */
public class MicrosoftLiveApi extends Api {

    private final Logger logger = Logger.getLogger(getClass());

    private static final String AUTHORIZE_URL = "https://consent.live.com/Connect.aspx";
    private static final String ACCESS_TOKEN_URL = "https://consent.live.com/AccessToken.aspx";
    private static final String REFRESH_TOKEN_URL = "https://consent.live.com/RefreshToken.aspx";
    private static final String CONTACTS_URL = "http://apis.live.net/V4.1/cid-%s/Contacts/AllContacts?$type=portable";

    /**
     * {@inheritDoc}
     */
    @Override
    public String getAuthorizationUrl() {
        return AUTHORIZE_URL;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getAccessTokenUrl(Verifier verifier) {
        return ACCESS_TOKEN_URL;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Map<String, String> getAccessTokenParameters(Verifier verifier) {
        verifier.addExtraParameter(MicrosoftConstant.IDTYPE, "CID");
        return super.getAccessTokenParameters(verifier);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getRefreshTokenUrl() {
        return REFRESH_TOKEN_URL;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public AccessTokenExtractor getAccessTokenExtractor() {
        return new MicrosoftAccessTokenExtractor();
    }

    public String getContacts(AccessToken accessToken) {

        String result = null;

        String url = String.format(CONTACTS_URL, accessToken.getExtraParameter(MicrosoftConstant.UID));

        Map<String, String> headers = new HashMap<String, String>();
        headers.put("Content-Type", "application/json");
        headers.put("Accept", "application/json");
        headers.put("Authorization", String.format("WRAP access_token=%s", accessToken.getAccessToken()));

        Request request = new Request(HttpVerb.GET, url);
        request.addHeaders(headers);
        Response response = request.send();

        logger.debug(request);
        logger.debug(response);
        logger.debug("Contacts: " + response.getBody());

        result = response.getBody();

        return result;
    }
}
