package com.oauth.wrap.extractor;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import com.oauth.wrap.model.AccessToken;
import com.oauth.wrap.model.Constant;
import com.oauth.wrap.model.RefreshToken;
import com.oauth.wrap.util.Preconditions;
import com.oauth.wrap.util.URLUtils;

/**
 * @author Oleksii Karpynskyi <okarpynskyi@gmail.com>
 * 
 */
public class AccessTokenExtractorImpl implements AccessTokenExtractor {

    protected static final Pattern ACCESS_TOKEN_REGEX = Pattern.compile(String.format("%s=([^&]+)", Constant.ACCESS_TOKEN));
    protected static final Pattern ACCESS_TOKEN_EXIRATION_REGEX = Pattern.compile(String.format("%s=([^&]+)", Constant.ACCESS_TOKEN_EXPIRATION));
    protected static final Pattern REFRESH_TOKEN_REGEX = Pattern.compile(String.format("%s=([^&]+)", Constant.REFRESH_TOKEN));
    protected static final Pattern ERROR_REASON_REGEX = Pattern.compile(String.format("%s=([^&]+)", Constant.ERROR_REASON));

    /**
     * {@inheritDoc}
     */
    public AccessToken extract(String response) {

        Preconditions.checkEmptyString(response, "Response body is incorrect. Can't extract a token from an empty string");

        AccessToken accessToken = new AccessToken();

        accessToken.setAccessToken(extract(response, ACCESS_TOKEN_REGEX));
        accessToken.setAccessTokenExpiration(extract(response, ACCESS_TOKEN_EXIRATION_REGEX));
        accessToken.setErrorReason(extract(response, ERROR_REASON_REGEX));

        // extract and set refresh token from access token response
        RefreshToken refreshToken = new RefreshToken();
        refreshToken.setRefreshToken(extract(response, REFRESH_TOKEN_REGEX));
        accessToken.setRefreshToken(refreshToken);

        return accessToken;
    }

    /**
     * 
     * @param response
     * @param p
     * @return
     */
    protected String extract(String response, Pattern p) {
        Matcher matcher = p.matcher(response);
        if (matcher.find() && matcher.groupCount() >= 1) {
            return URLUtils.formURLDecode(matcher.group(1));
        } else {
            return null;
            // throw new OAuthWRAPException("Response body is incorrect. Can't extract token and secret from this: '" +
            // response + "'");
        }
    }
}
