/**
 * 
 */
package com.oauth.wrap.model;

/**
 * @author Oleksii Karpynskyi <okarpynskyi@gmail.com>
 * 
 */
public class AccessToken extends Extension {

    /**
     * REQUIRED. The Access Token.
     */
    protected String accessToken;

    /**
     * OPTIONAL. The lifetime of the Access Token in seconds. For example, 3600 represents one hour.
     */
    protected String accessTokenExpiration;

    /**
     * REQUIRED. The Refresh Token.
     */
    protected RefreshToken refreshToken;

    /**
     * Default constructor
     */
    public AccessToken() {
        this(null);
    }

    /**
     * @param accessToken
     */
    public AccessToken(String accessToken) {
        this(accessToken, null, null);
    }

    /**
     * @param accessToken
     * @param accessTokenExpiration
     */
    public AccessToken(String accessToken, String accessTokenExpiration) {
        this(accessToken, accessTokenExpiration, null);
    }

    /**
     * @param accessToken
     * @param refreshToken
     * @param accessTokenExpiration
     */
    public AccessToken(String accessToken, String accessTokenExpiration, RefreshToken refreshToken) {
        super();
        this.accessToken = accessToken;
        this.accessTokenExpiration = accessTokenExpiration;
        this.refreshToken = refreshToken;
    }

    /**
     * @return the accessToken
     */
    public String getAccessToken() {
        return accessToken;
    }

    /**
     * @param accessToken
     */
    public void setAccessToken(String accessToken) {
        this.accessToken = accessToken;
    }

    /**
     * @return the refreshToken
     */
    public RefreshToken getRefreshToken() {
        return refreshToken;
    }

    /**
     * @param refreshToken
     * 
     */
    public void setRefreshToken(RefreshToken refreshToken) {
        this.refreshToken = refreshToken;
    }

    /**
     * @return the accessTokenExpiration
     */
    public String getAccessTokenExpiration() {
        return accessTokenExpiration;
    }

    /**
     * @param accessTokenExpiration
     * 
     */
    public void setAccessTokenExpiration(String accessTokenExpiration) {
        this.accessTokenExpiration = accessTokenExpiration;
    }

    /**
     * Check valid access token including refresh token check up
     * 
     * @return boolean
     */
    public boolean isValidIncludingRefreshToken() {
        return isValid() && refreshToken.isValid();
    }

    /**
     * Check if access token is valid and no error reason was occured
     * 
     * @return boolean
     */
    @Override
    public boolean isValid() {
        return !isErrorReason() && accessToken != null && accessTokenExpiration != null;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return "AccessToken [accessToken=" + accessToken + ", accessTokenExpiration=" + accessTokenExpiration + ", refreshToken=" + refreshToken + ", errorReason=" + errorReason + ", extraParameters=" + extraParameters + "]";
    }

}
