/**
 * 
 */
package com.oauth.wrap.model;

/**
 * @author Oleksii Karpynskyi <okarpynskyi@gmail.com>
 * 
 */
public class Config extends Extension {

    /**
     * Contains the client ID that identifies your application.
     */
    private String clientId;

    /**
     * Contains the client Secret that identifies your application.
     */
    private String clientSecret;

    /**
     * Provides the return URL to which the Windows Live service sends the verification code. The domain of this URL must match
     * the domain that you provided when you created your client ID. An example of a callback URL is
     * http://www.fabrikam.com/OAuth.aspx.
     */
    private String callback;

    /**
     * Optional. A string that is returned to your application with the consent response. This data is defined by the needs of
     * your application, and is opaque to the user. For example, if a user is visiting your site page,
     * www.fabrikam.com/xyz.htm, when you request consent, you can use this parameter to pass the value "xyz.htm" to the
     * consent service. When the user is redirected to your return URL, you can use this parameter to send the user to the
     * xyz.htm page.
     */
    private String clientState;

    /**
     * Contains one or more pairs of offers and actions. Each protected resource, such as Windows Live Messenger, has a
     * specific set of offers and actions. An example of a scope is WL_Contacts.View. You can submit multiple offers and
     * actions in a comma-delimited list, and then add them to the wrap_scope parameter.
     * http://msdn.microsoft.com/en-ca/library/ff749529.aspx
     * 
     * Possible values: WL_Activities.View, WL_Activities.Update, WL_Contacts.View, WL_Photos.View, WL_Profiles.View,
     * Messenger.SignIn
     */
    private String scope;

    /**
     * Empty constructor
     */
    public Config() {

    }

    /**
     * @param clientId
     * @param clientSecret
     */
    public Config(String clientId, String clientSecret) {
        this(clientId, clientSecret, null);
    }

    /**
     * @param clientId
     * @param clientSecret
     * @param callback
     */
    public Config(String clientId, String clientSecret, String callback) {
        this(clientId, clientSecret, callback, null);
    }

    /**
     * @param clientId
     * @param clientSecret
     * @param callback
     * @param clientState
     */
    public Config(String clientId, String clientSecret, String callback, String clientState) {
        this(clientId, clientSecret, callback, clientState, null);
    }

    /**
     * @param clientId
     * @param clientSecret
     * @param callback
     * @param clientState
     * @param scope
     */
    public Config(String clientId, String clientSecret, String callback, String clientState, String scope) {
        super();
        this.clientId = clientId;
        this.clientSecret = clientSecret;
        this.callback = callback;
        this.clientState = clientState;
        this.scope = scope;
    }

    /**
     * @param clientId
     */
    public void setClientId(String clientId) {
        this.clientId = clientId;
    }

    /**
     * @param clientSecret
     */
    public void setClientSecret(String clientSecret) {
        this.clientSecret = clientSecret;
    }

    /**
     * @param callback
     */
    public void setCallback(String callback) {
        this.callback = callback;
    }

    /**
     * @param clientState
     */
    public void setClientState(String clientState) {
        this.clientState = clientState;
    }

    /**
     * @param scope
     */
    public void setScope(String scope) {
        this.scope = scope;
    }

    /**
     * @return the clientId
     */
    public String getClientId() {
        return clientId;
    }

    /**
     * @return the clientSecret
     */
    public String getClientSecret() {
        return clientSecret;
    }

    /**
     * @return the callback
     */
    public String getCallback() {
        return callback;
    }

    /**
     * @return the clientState
     */
    public String getClientState() {
        return clientState;
    }

    /**
     * @return the scope
     */
    public String getScope() {
        return scope;
    }

    /**
     * 
     */
    @Override
    public boolean isValid() {
        return clientId != null && clientSecret != null;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return "Config [clientId=" + clientId + ", clientSecret=" + clientSecret + ", callback=" + callback + ", clientState=" + clientState + ", scope=" + scope + ", errorReason=" + errorReason + ", extraParameters=" + extraParameters + "]";
    }

}
