/**
 * 
 */
package com.oauth.wrap.model;

import java.util.HashMap;
import java.util.Map;

import com.oauth.wrap.exception.OAuthWRAPUnknownExtraParameterException;

/**
 * @author Oleksii Karpynskyi <okarpynskyi@gmail.com>
 * 
 */
abstract public class Extension {

    /**
     * Error description. REQUIRED if the User denies the request, Unsuccessful Access Token Response from Authorization
     * Server, If all the parameters are valid except that the Verification Code has expired or been revoked
     */
    protected String errorReason;

    /**
     * Any additional parameters, as defined by the Authorization Server.
     */
    protected Map<String, String> extraParameters;

    public Extension() {
        extraParameters = new HashMap<String, String>();
    }

    /**
     * @return the extraParameters
     */
    public Map<String, String> getExtraParameters() {
        return extraParameters;
    }

    /**
     * @param extraParameters
     */
    public void setExtraParameters(Map<String, String> extraParameters) {
        if (this.extraParameters != null) {
            this.extraParameters.putAll(extraParameters);
        } else {
            this.extraParameters = extraParameters;
        }
    }

    /**
     * 
     * @param name
     * @param value
     */
    public void addExtraParameter(String name, String value) {
        extraParameters.put(name, value);
    }

    /**
     * 
     * @param name
     */
    public String getExtraParameter(String name) {
        String param = null;
        if (extraParameters.containsKey(name)) {
            param = extraParameters.get(name);
        } else {
            throw new OAuthWRAPUnknownExtraParameterException(name, this);
        }
        return param;
    }

    /**
     * @return the errorReason
     */
    public String getErrorReason() {
        return errorReason;
    }

    /**
     * @param errorReason
     */
    public void setErrorReason(String errorReason) {
        this.errorReason = errorReason;
    }

    /**
     * 
     * @param name
     * @return boolean
     */
    public boolean delParameter(String name) {
        if (extraParameters.containsValue(name)) {
            extraParameters.remove(name);
            return true;
        }
        return false;
    }

    /**
     * @return boolean
     */
    public boolean isErrorReason() {
        return this.errorReason != null;
    }

    /**
     * Check for empty errors
     * 
     */
    public boolean isValid() {
        return !isErrorReason();
    }
}
