package com.oauth.wrap.api;

import static org.junit.Assert.assertEquals;

import org.junit.Before;
import org.junit.Test;

import com.oauth.wrap.model.Verifier;

public class ServiceBuilderTest {

    private ServiceBuilder builder;

    @Before
    public void setup() {
        builder = new ServiceBuilder();
    }

    @Test
    public void shouldReturnConfigDefaultValues() {
        Service service = builder.api(new ApiMock()).clientId("id").clientSecret("secret").build();
        assertEquals(service.getConfig().getClientId(), "id");
        assertEquals(service.getConfig().getClientSecret(), "secret");
    }

    @Test
    public void shouldAcceptValidCallbackUrl() {
        Service service = builder.api(new ApiMock()).clientId("id").clientSecret("secret").callback("http://example.com").build();
        assertEquals(service.getConfig().getClientId(), "id");
        assertEquals(service.getConfig().getClientSecret(), "secret");
        assertEquals(service.getConfig().getCallback(), "http://example.com");
    }

    @Test(expected = IllegalArgumentException.class)
    public void shouldNotAcceptAnInvalidUrlAsCallback() {
        builder.api(new ApiMock()).clientId("id").clientSecret("secret").callback("example.com").build();
    }

    @Test
    public void shouldAcceptAnScope() {
        Service service = builder.api(new ApiMock()).clientId("id").clientSecret("secret").scope("scope").build();
        assertEquals(service.getConfig().getClientId(), "id");
        assertEquals(service.getConfig().getClientSecret(), "secret");
        assertEquals(service.getConfig().getScope(), "scope");
    }

    public class ApiMock extends Api {

        @Override
        public String getAuthorizationUrl() {
            return null;
        }

        @Override
        public String getAccessTokenUrl(Verifier verifier) {
            return null;
        }

        @Override
        public String getRefreshTokenUrl() {
            return null;
        }
    }
}
