/**
 * 
 */
package com.oauth.wrap.extractor;

import static org.junit.Assert.assertEquals;

import org.junit.Before;
import org.junit.Test;

import com.oauth.wrap.model.AccessToken;
import com.oauth.wrap.model.Constant;

/**
 * @author Alex
 * 
 */
public class AccessTokenExtractorTest {

    protected AccessTokenExtractor extractor;

    @Before
    public void setup() {
        extractor = new AccessTokenExtractorImpl();
    }

    @Test
    public void shouldReturnValidAccessToken() {
        String response = String.format("%s=access_token&%s=access_token_expiration", Constant.ACCESS_TOKEN, Constant.ACCESS_TOKEN_EXPIRATION);
        AccessToken accessToken = extractor.extract(response);
        assertEquals(true, accessToken.isValid());
        assertEquals("access_token", accessToken.getAccessToken());
        assertEquals("access_token_expiration", accessToken.getAccessTokenExpiration());
    }

    @Test
    public void shouldReturnInvalidAccessToken() {
        String response = String.format("%s=access_token", Constant.ACCESS_TOKEN);
        AccessToken accessToken = extractor.extract(response);
        assertEquals(false, accessToken.isValid());
    }

    @Test
    public void shouldReturnInvalidAccessTokenWithErrorReason() {
        String response = String.format("%s=error_reason", Constant.ERROR_REASON);
        AccessToken accessToken = extractor.extract(response);
        assertEquals(false, accessToken.isValid());
        assertEquals(true, accessToken.isErrorReason());
        assertEquals("error_reason", accessToken.getErrorReason());
    }

    @Test
    public void shouldReturnValidAccessTokenWithValidRefreshToken() {
        String response = String.format("%s=access_token&%s=access_token_expiration&%s=refresh_token", Constant.ACCESS_TOKEN, Constant.ACCESS_TOKEN_EXPIRATION, Constant.REFRESH_TOKEN);
        AccessToken accessToken = extractor.extract(response);
        assertEquals(true, accessToken.isValid());
        assertEquals(true, accessToken.getRefreshToken().isValid());
        assertEquals("refresh_token", accessToken.getRefreshToken().getRefreshToken());
    }

    @Test
    public void shouldReturnValidAccessTokenWithInvalidRefreshToken() {
        String response = String.format("%s=access_token&%s=access_token_expiration", Constant.ACCESS_TOKEN, Constant.ACCESS_TOKEN_EXPIRATION);
        AccessToken accessToken = extractor.extract(response);
        assertEquals(true, accessToken.isValid());
        assertEquals(false, accessToken.getRefreshToken().isValid());
    }

}
