/**
 * 
 */
package com.oauth.wrap.model;

import static org.junit.Assert.assertEquals;

import java.util.HashMap;
import java.util.Map;

import org.junit.Before;
import org.junit.Test;

import com.oauth.wrap.exception.OAuthWRAPUnknownExtraParameterException;

/**
 * @author Alex
 * 
 */
public class ExtensionTest {

    Extension extension;

    @Before
    public void setup() {
        extension = new ExtensionMock();
    }

    @Test
    public void shouldReturnValidExtension() {
        assertEquals(true, extension.isValid());
    }

    @Test
    public void shouldReturnInvalidExtension() {
        extension.setErrorReason("errorReason");
        assertEquals("errorReason", extension.getErrorReason());
        assertEquals(false, extension.isValid());
    }

    @Test
    public void shouldReturnExtraParameters() {
        Map<String, String> extraParameters = new HashMap<String, String>();
        extraParameters.put("parameter1", "value1");
        extraParameters.put("parameter2", "value2");
        extension.setExtraParameters(extraParameters);
        assertEquals(2, extension.getExtraParameters().size());
        assertEquals(extraParameters, extension.getExtraParameters());
        assertEquals("value1", extension.getExtraParameter("parameter1"));
    }

    @Test(expected = OAuthWRAPUnknownExtraParameterException.class)
    public void shouldTrowUnknownExtraParameterException() {
        extension.getExtraParameter("parameter1");
    }

    public class ExtensionMock extends Extension {
    }
}
