package com.oauth.wrap.model;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import org.junit.Before;
import org.junit.Test;

import com.oauth.wrap.model.mock.UrlConnectionMock;

public class RequestTest {

    private Request getRequest;
    private Request postRequest;
    private UrlConnectionMock connection;

    @Before
    public void setup() throws Exception {
        connection = new UrlConnectionMock();
        postRequest = new Request(HttpVerb.POST, "http://example.com");
        postRequest.addBodyParameter("param", "value");
        postRequest.addBodyParameter("param with spaces", "value with spaces");
        postRequest.setConnection(connection);
        getRequest = new Request(HttpVerb.GET, "http://example.com?qsparam=value&other+param=value+with+spaces");
        getRequest.setConnection(connection);
    }

    @Test
    public void shouldSetRequestVerb() {
        getRequest.send();
        assertEquals("GET", connection.getRequestMethod());
    }

    @Test
    public void shouldGetQueryStringParameters() {
        assertEquals(2, getRequest.getQueryStringParams().size());
        assertEquals(0, postRequest.getQueryStringParams().size());
        assertTrue(getRequest.getQueryStringParams().containsKey("qsparam"));
        assertTrue(getRequest.getQueryStringParams().get("qsparam").equals("value"));
    }

    @Test
    public void shouldAddRequestHeaders() {
        getRequest.addHeader("Header", "1");
        getRequest.addHeader("Header2", "2");
        getRequest.send();
        assertEquals(2, getRequest.getHeaders().size());
        assertEquals(2, connection.getHeaders().size());
    }

    @Test
    public void shouldSetBodyParamsAndAddContentLength() {
        assertEquals("param=value&param+with+spaces=value+with+spaces", postRequest.getBodyContents());
        postRequest.send();
        assertTrue(connection.getHeaders().containsKey("Content-Length"));
    }

    @Test
    public void shouldAllowAddingQuerystringParametersAfterCreation() {
        Request request = new Request(HttpVerb.GET, "http://example.com?one=val");
        request.addQuerystringParameter("two", "other val");
        request.addQuerystringParameter("more", "params");
        assertEquals(3, request.getQueryStringParams().size());
    }

    @Test
    public void shouldHandleQueryStringSpaceEncodingProperly() {
        assertTrue(getRequest.getQueryStringParams().get("other param").equals("value with spaces"));
    }

}
